==> haskell-http-api-data-0.3.5-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.3.5
id: http-api-data-0.3.5-FQELOjH2uHJHZkd7koPyb2
key: http-api-data-0.3.5-FQELOjH2uHJHZkd7koPyb2
license: BSD3
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    Please see README.md
category: Web
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
exposed: True
exposed-modules:
    Web.HttpApiData Web.FormUrlEncoded Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData
abi: d4de7acbea6237c6736261f777d732c4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-api-data-0.3.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-api-data-0.3.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-api-data-0.3.5
hs-libraries: HShttp-api-data-0.3.5-FQELOjH2uHJHZkd7koPyb2
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    uri-bytestring-0.2.3.1-LQPYVpiQXMMJVaCbfDcGnc
    uuid-types-1.0.3-9AR9NqIFJzo61iW1wAnWIZ
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.3.6-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.3.6
id: http-api-data-0.3.6-J82vsTCH5jB5BG5Viozokg
key: http-api-data-0.3.6-J82vsTCH5jB5BG5Viozokg
license: BSD3
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    Please see README.md
category: Web
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
exposed: True
exposed-modules:
    Web.HttpApiData Web.FormUrlEncoded Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData
abi: 80a472212e2f1791dcc817503627e2db
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-api-data-0.3.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-api-data-0.3.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-api-data-0.3.6
hs-libraries: HShttp-api-data-0.3.6-J82vsTCH5jB5BG5Viozokg
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    uri-bytestring-0.2.3.1-JYd5pcFSOt4LtssEai7Vf5
    uuid-types-1.0.3-9AR9NqIFJzo61iW1wAnWIZ
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
